
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.037
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "automatically load test helpers by walking the directory tree",
  "dist_author" => [
    "Branislav Zahradn\x{ed}k <barney.cpan\@gmail.com>"
  ],
  "dist_name" => "Test-Load-Helper",
  "dist_version" => "1.0.1",
  "license" => "artistic_2",
  "module_name" => "Test::Load::Helper",
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => 0,
    "Path::Tiny" => "0.018",
    "perl" => "5.014",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "Path::Tiny" => "0.018",
    "Test::EOL" => 0,
    "Test::YAFT" => 0,
    "constant" => 0,
    "require::relative" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Path::Tiny" => "0.018",
  "Test::EOL" => 0,
  "Test::YAFT" => 0,
  "constant" => 0,
  "require::relative" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
